From 74583a02efbbc773abbbf241f8db6aa8d3f1ef36 Mon Sep 17 00:00:00 2001
From: Aleksander Alekseev <aleksander@timescale.com>
Date: Thu, 7 Nov 2024 17:23:35 +0300
Subject: [PATCH v1] Make LMT an ignored date/time keyword

We may specify LMT time zone when casting TimestampTz's to TEXT but failed
to parse it when casting types in the opposite direction. As a result
the following query failed:

SET DateStyle to Postgres;
SELECT '1000-01-01' :: timestamptz :: text :: timestamptz;

Fix this by adding LMT to the list of ignored date/time keywords.

Aleksander Alekseev, reviewed by TODO FIXME
Discussion: https://postgr.es/m/CAJ7c6TOATjJqvhnYsui0%3DCO5XFMF4dvTGH%2BskzB--jNhqSQu5g%40mail.gmail.com
---
 src/backend/utils/adt/datetime.c          |  1 +
 src/test/regress/expected/timestamptz.out | 16 ++++++++++++++++
 src/test/regress/sql/timestamptz.sql      |  7 +++++++
 3 files changed, 24 insertions(+)

diff --git a/src/backend/utils/adt/datetime.c b/src/backend/utils/adt/datetime.c
index 600b59190e..65218356bd 100644
--- a/src/backend/utils/adt/datetime.c
+++ b/src/backend/utils/adt/datetime.c
@@ -139,6 +139,7 @@ static const datetkn datetktbl[] = {
 	{"july", MONTH, 7},
 	{"jun", MONTH, 6},
 	{"june", MONTH, 6},
+	{"lmt", IGNORE_DTF, 0},		/* "lmt" (throwaway) */
 	{"m", UNITS, DTK_MONTH},	/* "month" for ISO input */
 	{"mar", MONTH, 3},
 	{"march", MONTH, 3},
diff --git a/src/test/regress/expected/timestamptz.out b/src/test/regress/expected/timestamptz.out
index b437613ac8..b8ea3d3405 100644
--- a/src/test/regress/expected/timestamptz.out
+++ b/src/test/regress/expected/timestamptz.out
@@ -3306,3 +3306,19 @@ select make_timestamptz(1999, 12, 31, 24, 0, 0);
  Sat Jan 01 00:00:00 2000 PST
 (1 row)
 
+-- check that LMT is an ignored date/time keyword
+select timestamptz 'Wed Jan 01 00:00:00 1000 LMT';
+         timestamptz          
+------------------------------
+ Wed Jan 01 00:00:00 1000 LMT
+(1 row)
+
+-- required for this to work:
+set datestyle to Postgres;
+select '1000-01-01' :: timestamptz :: text :: timestamptz;
+         timestamptz          
+------------------------------
+ Wed Jan 01 00:00:00 1000 LMT
+(1 row)
+
+reset datestyle;
diff --git a/src/test/regress/sql/timestamptz.sql b/src/test/regress/sql/timestamptz.sql
index 6b91e7eddc..13e902db78 100644
--- a/src/test/regress/sql/timestamptz.sql
+++ b/src/test/regress/sql/timestamptz.sql
@@ -675,3 +675,10 @@ SELECT age(timestamptz '-infinity', timestamptz '-infinity');
 -- test timestamp near POSTGRES_EPOCH_JDATE
 select timestamptz '1999-12-31 24:00:00';
 select make_timestamptz(1999, 12, 31, 24, 0, 0);
+
+-- check that LMT is an ignored date/time keyword
+select timestamptz 'Wed Jan 01 00:00:00 1000 LMT';
+-- required for this to work:
+set datestyle to Postgres;
+select '1000-01-01' :: timestamptz :: text :: timestamptz;
+reset datestyle;
-- 
2.47.0

